==> hawkular-wildfly-agent-0.13.0.Final-sources.jar: org/hawkular/agent/monitor/extension/ManagedServersDefinition.java <==
/*
 * Copyright 2015 Red Hat, Inc. and/or its affiliates
 * and other contributors as indicated by the @author tags.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.hawkular.agent.monitor.extension;

import java.util.Arrays;
import java.util.Collection;
import java.util.List;

import org.jboss.as.controller.AttributeDefinition;
import org.jboss.as.controller.PathElement;
import org.jboss.as.controller.PersistentResourceDefinition;
import org.jboss.as.controller.registry.OperationEntry.Flag;

public class ManagedServersDefinition extends PersistentResourceDefinition {

    public static final ManagedServersDefinition INSTANCE = new ManagedServersDefinition();

    static final String MANAGED_SERVERS = "managed-servers";

    private ManagedServersDefinition() {
        super(PathElement.pathElement(MANAGED_SERVERS, "default"),
                SubsystemExtension.getResourceDescriptionResolver(MANAGED_SERVERS),
                ManagedServersAdd.INSTANCE,
                ManagedServersRemove.INSTANCE,
                Flag.RESTART_RESOURCE_SERVICES,
                Flag.RESTART_RESOURCE_SERVICES);
    }

    @Override
    public Collection<AttributeDefinition> getAttributes() {
        return Arrays.asList(ManagedServersAttributes.ATTRIBUTES);
    }

    @Override
    protected List<? extends PersistentResourceDefinition> getChildren() {
        return Arrays.asList(
                LocalDMRDefinition.INSTANCE,
                RemoteDMRDefinition.INSTANCE,
                RemoteJMXDefinition.INSTANCE);
    }
}

==> hawkular-wildfly-agent-0.22.0.Final-sources.jar: org/hawkular/agent/monitor/extension/ManagedServersDefinition.java <==
/*
 * Copyright 2015-2016 Red Hat, Inc. and/or its affiliates
 * and other contributors as indicated by the @author tags.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.hawkular.agent.monitor.extension;

import java.util.Arrays;
import java.util.Collection;
import java.util.List;

import org.jboss.as.controller.AttributeDefinition;
import org.jboss.as.controller.PathElement;
import org.jboss.as.controller.PersistentResourceDefinition;
import org.jboss.as.controller.registry.OperationEntry.Flag;

public class ManagedServersDefinition extends PersistentResourceDefinition {

    public static final ManagedServersDefinition INSTANCE = new ManagedServersDefinition();

    static final String MANAGED_SERVERS = "managed-servers";

    private ManagedServersDefinition() {
        super(PathElement.pathElement(MANAGED_SERVERS, "default"),
                SubsystemExtension.getResourceDescriptionResolver(MANAGED_SERVERS),
                ManagedServersAdd.INSTANCE,
                ManagedServersRemove.INSTANCE,
                Flag.RESTART_RESOURCE_SERVICES,
                Flag.RESTART_RESOURCE_SERVICES);
    }

    @Override
    public Collection<AttributeDefinition> getAttributes() {
        return Arrays.asList(ManagedServersAttributes.ATTRIBUTES);
    }

    @Override
    protected List<? extends PersistentResourceDefinition> getChildren() {
        return Arrays.asList(
                LocalDMRDefinition.INSTANCE,
                RemoteDMRDefinition.INSTANCE,
                RemoteJMXDefinition.INSTANCE,
                RemotePrometheusDefinition.INSTANCE);
    }
}
